/**
 * @file file.h RVP file transfert functions
 *
 * gaim
 *
 * Copyright (C) 2005 Fabien Carrion <fabien.carrion@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef _RVP_FILE_H_
#define _RVP_FILE_H_

#define RVP_GUID "{5D3E02AB-6190-11d3-BBBB-00C04F795683}"
#define RVP_PORT1 6891
#define RVP_PORT2 11178

typedef struct _RvpFile RvpFile;

struct _RvpFile
{
  int   inpa1;
  int   listenfd1;  /* socket write to for file transfert */
  int   inpa2;
  int   listenfd2;  /* socket write to for file transfert */
  int   fd;         /* socket read from for file transfert */
  int   cookie;     /* cookie for the file transfert      */
  int   authcookie; /* authcookie for the file transfert  */
  gchar *ip;
  int port1;
  int port2;
  int headersize;
  gboolean canceled;
};



/**
 * Find a RVP file transfert from the buddy and the cookie.
 *
 * @param buddy  The buddy with who we're doing the file transfert.
 * @param cookie The cookie refering the transaction.
 *
 * @return The transaction reference.
 */
GaimXfer *rvp_xfer_find(GaimBuddy *buddy, int cookie);

/**
 * Create a new RvpFile structure.
 *
 * @return The RvpFile structure.
 */
RvpFile *rvp_file_new(void);

/**
 * Init a RVP file transfert.
 *
 * @param xfer The file transfert structure.
 */
void rvp_xfer_init(GaimXfer *xfer);

/**
 * Start a RVP file transfert.
 * Send the headers
 *
 * @param xfer The file transfert structure.
 */
void rvp_xfer_start_send(GaimXfer *xfer);

/**
 * Start a RVP file transfert.
 * Send the headers
 *
 * @param xfer The file transfert structure.
 */
void rvp_xfer_start_recv(GaimXfer *xfer);

/**
 * End a RVP file transfert.
 *
 * @param xfer The file transfert structure.
 */
void rvp_xfer_end(GaimXfer *xfer);

/**
 * Read some byte for a RVP file transfert.
 *
 * @param buffer The buffer where to put some bytes.
 * @param xfer The file transfert structure.
 */
ssize_t
rvp_xfer_read(guchar **buffer, GaimXfer *xfer);

/**
 * Read some byte for a RVP file transfert.
 *
 * @param buffer The buffer where to put some bytes.
 * @param xfer The file transfert structure.
 *
 * @return the number of bytes received
 */
ssize_t
rvp_xfer_read(guchar **buffer, GaimXfer *xfer);

/**
 * Write some byte for a RVP file transfert.
 *
 * @param buffer The buffer where to get some bytes to send.
 * @param size the size of the buffer.
 * @param xfer The file transfert structure.
 *
 * @return the number of bytes sent
 */
ssize_t
rvp_xfer_write(const guchar *buffer, size_t size, GaimXfer *xfer);

/**
 * Cancel a RVP file transfert.
 *
 * @param xfer The file transfert structure.
 */
void rvp_xfer_cancel(GaimXfer *xfer);

/**
 * Cancel and notify remote user a RVP file transfert.
 *
 * @param xfer The file transfert structure.
 */
void rvp_xfer_cancel_notify(GaimXfer *xfer);

#endif /* _RVP_FILE_H_ */
