/**
 * @file httpconn.h RVP http connection functions
 *
 * gaim
 *
 * Copyright (C) 2005 Fabien Carrion <fabien.carrion@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef _RVP_HTTPCONN_H_
#define _RVP_HTTPCONN_H_

#define RVP_CONNECT_STEPS 6

typedef struct _RvpHttpconn RvpHttpconn;

struct _RvpHttpconn
{
  GaimConnection *gc;
  int fd;
  int inpa;

  gchar *method;
  gchar *uri;
  gchar *auth_key;

  gchar *host;
  gchar *header;
  gchar *body;
  gpointer option;

  int connection_step;

  gboolean callback;

  /** The analyze function */
  void (*analyze)(RvpHttpconn *hc, const gchar *receive);
};

/**
 * Get an HTTP header from a buffer.
 *
 * @param  receive The HTTP buffer.
 * @param  header  The HTTP header to get.
 * @return The HTTP header value.
 */
gchar *getHeader(const gchar *receive, const gchar *header);


/**
 * Send datas to the server according to a Httpconn structure.
 *
 * @param data The Httpconn structure.
 * @param source The socket.
 * @param condition Read or Write.
 *
 */
void rvp_http_send(gpointer data, gint source, GaimInputCondition condition);

/**
 * Receive datas from the server according to a Httpconn structure.
 *
 * @param data The Httpconn structure.
 * @param source The socket.
 * @param condition Read or Write.
 *
 */
void rvp_http_receive(gpointer data, gint source, GaimInputCondition condition);

#endif
