/**
 * @file msg.h RVP send NOTIFY message to buddy functions
 *
 * gaim
 *
 * Copyright (C) 2005 Fabien Carrion <fabien.carrion@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef _RVP_MSG_H_
#define _RVP_MSG_H_

/**
 * invites action.
 *
 * @param session     The RVP session.
 * @param buddy       The buddy to notify.
 */
void rvp_invites_notify(RvpSession *session, GaimBuddy *buddy);

/**
 * typing message action.
 *
 * @param session     The RVP session.
 * @param buddy       The buddy to notify.
 */
void rvp_typing_notify(RvpSession *session, GaimBuddy *buddy);

/**
 * send message action.
 *
 * @param session     The RVP session.
 * @param buddy       The buddy to notify.
 * @param message     The message to send.
 */
void rvp_send_notify(RvpSession *session, GaimBuddy *buddy, const gchar *message);

/**
 * send request file transfert action.
 *
 * @param session     The RVP session.
 * @param buddy       The buddy to notify.
 * @param xfer        The file to send.
 */
void rvp_send_request_file(RvpSession *session, GaimBuddy *buddy, GaimXfer *xfer);

/**
 * send accept file transfert action.
 *
 * @param session     The RVP session.
 * @param buddy       The buddy to notify.
 * @param xfer        The file to receive.
 */
void rvp_send_accept_file(RvpSession *session, GaimBuddy *buddy, GaimXfer *xfer);

/**
 * send accept file transfert action with info.
 *
 * @param session     The RVP session.
 * @param buddy       The buddy to notify.
 * @param xfer        The file to receive.
 */
void rvp_send_accept_info_file(RvpSession *session, GaimBuddy *buddy, GaimXfer *xfer);

/**
 * send cancel file transfert action.
 *
 * @param session     The RVP session.
 * @param buddy       The buddy to notify.
 * @param xfer        The file to receive.
 */
void rvp_send_cancel_timeout_file(RvpSession *session, GaimBuddy *buddy, GaimXfer *xfer);

#endif /* _RVP_MSG_H_ */
