/**
 * @file session.h RVP session functions
 *
 * gaim
 *
 * Copyright (C) 2005 Fabien Carrion <fabien.carrion@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef _RVP_SESSION_H_
#define _RVP_SESSION_H_

typedef struct _RvpSession RvpSession;
typedef struct _RvpBuddy   RvpBuddy;

#define RVP_PORT 80

struct _RvpSession
{
  GaimAccount *account;

  gchar *host;
  gchar *domain;
  gchar *user;
  gchar *password;
  const gchar *ip;

  gboolean connected;

  int fd;
  int listenfd;
  int subscriptionid;
  int subscriptionlifetime;

  int state;
  int state_lifetime;
  int modstate;
};

struct _RvpBuddy
{
  gchar *user;           /* user */
  gchar *host;           /* host */
  gint  sid;             /* Client buddy subscription id */
  gint  slt;             /* Client renew subscription */
  gint  s_cb;            /* Id for the subscription renew */
  gchar *sessionid;      /* sessionid for conversation */
  RvpSession *session;
  GSList *xfer;          /* opened file transfert */
};


/**
 * Creates an RVP session.
 *
 * @param account The account.
 *
 * @return The new RVP session.
 */
RvpSession *rvp_session_new(GaimAccount *account);

/**
 * Connects to, initiates and login an RVP session.
 *
 * @param session     The RVP session.
 * @param gc          The RVP connection.
 */
void rvp_session_login(RvpSession *session, GaimConnection *gc);

/**
 * Logout an RVP session.
 *
 * @param session The RVP session to logout.
 */
void rvp_session_logout(RvpSession *session);

#endif /* _RVP_SESSION_H_ */
