/**
 * @file state.h State functions and definitions
 *
 * gaim
 *
 * Gaim is the legal property of its developers, whose names are too numerous
 * to list here.  Please refer to the COPYRIGHT file distributed with this
 * source distribution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef _RVP_STATE_H_
#define _RVP_STATE_H_

/**
 * Away types.
 */
typedef enum
{
	RVP_ONLINE  = 0,
	RVP_BUSY    = 1,
	RVP_IDLE    = 2,
	RVP_BRB     = 3,
	RVP_AWAY    = 4,
	RVP_PHONE   = 5,
	RVP_LUNCH   = 6,
	RVP_OFFLINE = 7,
	RVP_HIDDEN  = 8

} RvpAwayType;

/**
 * Changes the status of the user.
 *
 * @param session The RVP session.
 * @param state   The new state.
 */
void rvp_change_status(RvpSession *session, RvpAwayType state);

/**
 * Returns the string representation of an away type.
 *
 * @param type The away type.
 *
 * @return The string representation of the away type.
 */
const char *rvp_away_get_text(RvpAwayType type);

const char *rvp_state_get_text(RvpAwayType state);

/**
 * Returns the number representation of an away type.
 *
 * @param state The away type.
 *
 * @return The number representation of the away type.
 */
int rvp_state_get_number(const char *state);

#endif /* _RVP_STATE_H_ */
