/**
 * @file subscriptions.c RVP subscriptions buddy functions
 *
 * gaim
 *
 * Copyright (C) 2005 Fabien Carrion <fabien.carrion@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "internal.h"

#include "account.h"
#include "debug.h"
#include "xmlnode.h"
#include "server.h"
#include "notify.h"

#include "session.h"
#include "httpconn.h"
#include "subscriptions.h"

void
rvp_subscriptions_cb(RvpHttpconn *hc, const gchar *receive)
{
  GaimBuddy *b = NULL;

  g_return_if_fail(hc != NULL);
  g_return_if_fail(receive != NULL);

  b = hc->option;
  g_return_if_fail(b != NULL);

  if (hc->inpa > 0)
    gaim_input_remove(hc->inpa);

  if (strncmp(receive, "HTTP/1.1 404 Not Found\r\n", 24) == 0)
    {
      gaim_debug(GAIM_DEBUG_ERROR, "rvp", "rvp_subscriptions_cb failed, buddy %s not found\n",
                 gaim_buddy_get_name(b));
      gaim_blist_remove_buddy(b);
    }

  if (strncmp(receive, "HTTP/1.1 200 Successful\r\n", 25) == 0)
    {
      gaim_debug(GAIM_DEBUG_INFO, "rvp", "rvp_subscriptions_cb success %s\n",
                 gaim_buddy_get_name(b));
    }

  return;
}

void
rvp_subscriptions(RvpSession *session, GaimBuddy *buddy)
{
  GaimConnection *gc = NULL;

  RvpHttpconn *hc = g_new0(RvpHttpconn, 1);
  gchar buf[80];

  RvpBuddy *rvpb = NULL;

  g_return_if_fail(session != NULL);
  g_return_if_fail(session->connected);
  g_return_if_fail(buddy != NULL);

  g_return_if_fail(hc != NULL);

  gc = gaim_account_get_connection(session->account);
  g_return_if_fail(gc != NULL);

  rvpb = buddy->proto_data;
  g_return_if_fail(rvpb != NULL);

  gaim_debug(GAIM_DEBUG_INFO, "rvp", "rvp_subscriptions %s\n",
             gaim_buddy_get_name(buddy));

  hc->gc = gc;
  hc->connection_step = 1;

  if (gc->inpa > 0)
    gaim_input_remove(gc->inpa);

  hc->method = "SUBSCRIPTIONS";
  hc->uri = g_strdup_printf(
                            "/instmsg/aliases/%s",
                            rvpb->user);
  hc->callback = FALSE;
  hc->option = (gpointer *)buddy;
  hc->host = g_strdup(rvpb->host);
  hc->body = g_strdup("");

  hc->header = g_strdup_printf(
			       "%s %s HTTP/1.1\r\n"
			       "Notification-Type: update/propchange\r\n"
			       "Host: %s\r\n"
			       "RVP-Notifications-Version: 0.2\r\n"
			       "RVP-From-Principal: http://%s/instmsg/aliases/%s\r\n"
                               "Content-Length: 0\r\n",
                               hc->method,
                               hc->uri,
			       hc->host,
			       session->host,
			       session->user);
  hc->analyze = rvp_subscriptions_cb;

  if (gaim_proxy_connect(session->account, hc->host, RVP_PORT,
                         rvp_http_send, hc) != 0)
    {
      g_snprintf(buf, sizeof buf, _("buddy %s not found."),
                 gaim_buddy_get_name(buddy));
      gaim_notify_error(gc, NULL, _("Subscriptions Impossible"), buf);
      gaim_blist_remove_buddy(buddy);
    }

  return;
}
